@@ -43,7 +43,7 @@ class Migration(SchemaMigration):
             ('slug', self.gf('django.db.models.fields.SlugField')(unique=True, max_length=200, blank=True)),
             ('author', self.gf('django.db.models.fields.related.ForeignKey')(to=orm[user_orm_label], null=True, blank=True)),
             ('synopsis', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
-            ('image', self.gf('filebrowser.fields.FileBrowseField')(max_length=250, null=True, blank=True)),
+            ('image', self.gf('django.db.models.fields.ImageField')(max_length=250, null=True, blank=True)),
             ('content', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
             ('status', self.gf('django.db.models.fields.CharField')(default='draft', max_length=50)),
             ('is_highlighted', self.gf('django.db.models.fields.BooleanField')(default=False)),
@@ -107,7 +107,7 @@ class Migration(SchemaMigration):
             'content': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
             'creation_date': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
             u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
-            'image': ('filebrowser.fields.FileBrowseField', [], {'max_length': '250', 'null': 'True', 'blank': 'True'}),
+            'image': ('django.db.models.fields.ImageField', [], {'max_length': '250', 'null': 'True', 'blank': 'True'}),
             'is_highlighted': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
             'last_modified': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'auto_now_add': 'True', 'blank': 'True'}),
             'slug': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '200', 'blank': 'True'}),
